pub struct AbilityTemplate {Show 18 fields
pub id: AbilityId,
pub is_fight_ui_visible: bool,
pub fight_ui_visibility: AbilityFightUiVisibility,
pub name: I18nString,
pub start_behavior: Option<String>,
pub behavior: Option<String>,
pub icon_url: String,
pub icon_path: String,
pub cooldown: u64,
pub is_gacha_ability: bool,
pub available_to_bots: bool,
pub rarity_id: AbilityRarityId,
pub description: I18nString,
pub description_values_script: Option<String>,
pub vfx_object_path: String,
pub cast_type: AbilityCastType,
pub target_type: AbilityTargetType,
pub range: i64,
}Fields
id: AbilityIdis_fight_ui_visible: boolfight_ui_visibility: AbilityFightUiVisibilityname: I18nStringstart_behavior: Option<String>behavior: Option<String>icon_url: Stringicon_path: Stringcooldown: u64is_gacha_ability: boolavailable_to_bots: boolrarity_id: AbilityRarityIddescription: I18nStringdescription_values_script: Option<String>vfx_object_path: Stringcast_type: AbilityCastTypetarget_type: AbilityTargetTyperange: i64Trait Implementations
Sourceimpl Clone for AbilityTemplate
impl Clone for AbilityTemplate
Sourcefn clone(&self) -> AbilityTemplate
fn clone(&self) -> AbilityTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AbilityTemplate
impl Debug for AbilityTemplate
Sourceimpl Default for AbilityTemplate
impl Default for AbilityTemplate
Sourcefn default() -> AbilityTemplate
fn default() -> AbilityTemplate
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AbilityTemplate
impl<'de> Deserialize<'de> for AbilityTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromWasmAbi for AbilityTemplatewhere
Self: DeserializeOwned,
impl FromWasmAbi for AbilityTemplatewhere
Self: DeserializeOwned,
Sourceimpl JsonSchema for AbilityTemplate
impl JsonSchema for AbilityTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for AbilityTemplatewhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for AbilityTemplatewhere
Self: DeserializeOwned,
Sourceimpl PartialEq for AbilityTemplate
impl PartialEq for AbilityTemplate
Sourceimpl RefFromWasmAbi for AbilityTemplatewhere
Self: DeserializeOwned,
impl RefFromWasmAbi for AbilityTemplatewhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<AbilityTemplate>
type Anchor = SelfOwner<AbilityTemplate>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for AbilityTemplate
impl Serialize for AbilityTemplate
Sourceimpl Tsify for AbilityTemplate
impl Tsify for AbilityTemplate
const DECL: &'static str = "export interface AbilityTemplate {\n id: AbilityId;\n is_fight_ui_visible: boolean;\n fight_ui_visibility: AbilityFightUiVisibility;\n name: I18nString;\n start_behavior?: string | null;\n behavior?: string | null;\n icon_url: string;\n icon_path: string;\n cooldown: number;\n is_gacha_ability: boolean;\n available_to_bots?: boolean;\n rarity_id: AbilityRarityId;\n description: I18nString;\n description_values_script: string | null;\n vfx_object_path: string;\n cast_type: AbilityCastType;\n target_type?: AbilityTargetType;\n range?: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for AbilityTemplatewhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for AbilityTemplatewhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl WasmDescribeVector for AbilityTemplate
impl WasmDescribeVector for AbilityTemplate
impl Eq for AbilityTemplate
impl StructuralPartialEq for AbilityTemplate